@@ -3,7 +3,7 @@ package Date::RangeParser::EN;
 our $AUTHORITY = 'cpan:GSG';
 # ABSTRACT: Parse plain English date/time range strings
 use version;
-our $VERSION = 'v1.0.1'; # VERSION
+our $VERSION = 'v1.1.0'; # VERSION
 
 use strict;
 use warnings;
@@ -12,6 +12,11 @@ use utf8;
 use Date::Manip;
 use DateTime;
 
+my $dm_backend = $Date::Manip::Backend || '';
+if ($Date::Manip::VERSION lt '6' or $dm_backend eq 'DM5') {
+    warnings::warnif 'deprecated', "Versions of Date::Manip prior to 6.0.0 and DM5 backend will be deprecated in future releases.";
+}
+
 #pod =head1 NAME
 #pod
 #pod Date::RangeParser::EN - Parser for plain English date/time range strings
@@ -237,7 +242,11 @@ sub new
 #pod   this coming WEEKDAY               : the WEEKDAY that is in the week after this, midnight to midnight
 #pod   this coming Thursday
 #pod
-#pod   NUMBER Business days ago        : past number of business days relative to now until now
+#pod   NUMBER Business days ago          : past number of business days relative to now until now
+#pod
+#pod   NUMBER weekdays ago               : past number of weekdays relative to now until now
+#pod
+#pod   LAST or PAST NUMBER weekdays ago  : past number of weekdays relative to now until now
 #pod
 #pod   NUMBER PERIOD hence               : now to a future date relative to now
 #pod   4 months hence
@@ -383,6 +392,12 @@ sub parse_range
     # the following regex is anchored to the end of the string.
     $string =~ s/2nd$/second/;
 
+    # Handle weekdays as we do business days
+    if ($string =~ /^(?:last|past)\s?(\d+)?\s?weekdays?/) {
+        my $interval = $1 || 1;
+        $string =~ s/^(?:last|past)\s?(\d+)?\s?weekdays?/$interval business days ago/;
+    }
+
     # Sometimes we get a bare US style date, but the user has used dashes.
     # Let's de-scramble that before moving on.
     $string = $self->_convert_from_us_dashed($string);
@@ -1175,7 +1190,7 @@ Date::RangeParser::EN - Parse plain English date/time range strings
 
 =head1 VERSION
 
-version v1.0.1
+version v1.1.0
 
 =head1 SYNOPSIS
 
@@ -1313,7 +1328,11 @@ More formally, this will parse the following kinds of date strings:
   this coming WEEKDAY               : the WEEKDAY that is in the week after this, midnight to midnight
   this coming Thursday
 
-  NUMBER Business days ago        : past number of business days relative to now until now
+  NUMBER Business days ago          : past number of business days relative to now until now
+
+  NUMBER weekdays ago               : past number of weekdays relative to now until now
+
+  LAST or PAST NUMBER weekdays ago  : past number of weekdays relative to now until now
 
   NUMBER PERIOD hence               : now to a future date relative to now
   4 months hence
